local myname, ns = ...

local path = ns.path

local RELIC_FRAGMENT = 186685 -- relic fragment
local rift_active = {requires_buff={352795, 354870, any=true}}

local researched = ns.nodeMaker{
    IsActive = function(point)
        return select(3, GetFactionInfoByID(2472)) >= point.research
    end,
}

ns.RegisterPoints(1961, { -- Korthia
    [29505345] = { -- Anima Laden Egg
        achievement=15099, criteria=52241,
        quest=64244,
        loot={
            187349, -- Anima Laden Egg
        },
    },

    [47502920] = { -- Dislodged Nest
        achievement=15099, criteria=52240,
        quest=64241,
        minimap=true,
        loot={
            {187339, toy=true}, -- Silver Shardhide Whistle
        },
        note="Get {spell:355181} from a Noxious Moth; use {spell:355131} on {npc:178547} and ride into the tree",
    },

    [50458445] = { -- Displaced Relic
        achievement=15099, criteria=52242,
        quest=64252,
        loot={
            187350, --Displaced Relic (300 research)
        },
    },

    [68902990] = { -- Forgotten Feather
        achievement=15099, criteria=52237,
        quest=64234,
        loot={
            {187051, toy=true}, -- Forgotten Feather
        },
        note="Jump down from Keeper's Respite",
    },

    [38354295] = { -- Glittering Nest Materials
        achievement=15099, criteria=52236,
        quest=64222,
    },

    [42505595] = { -- Infected Vestige
        achievement=15099, criteria=52245,
        quest=64264,
        loot={
            187354, -- Abandoned Broker Satchel
        },
        note="In cave",
    },

    [52901475] = { -- Lost Memento
        achievement=15099, criteria=52238,
        quest=64238,
    },

    [45356715] = { -- Offering Box
        achievement=15099, criteria=52246,
        quest=64268,
        -- requires_item=187033,
        loot={
            {187344, toy=true}, -- Offering Kit Maker
        },
        note="Find {item:187033} in the nearby ruins, on the top of the west wall",
    },
    [43556770] = path({achievement=15099, criteria=52246, quest=64268, inbag=187033, label="{item:187033}", atlas="MantidTower"}), -- Small Offering Key

    [62055550] = { -- Spectral Bound Chest
        quest=64247,
        loot = {
            -- 187020, -- Necrobinder's Shoulderpads (confirm? it's in the caches...)
            187026, -- Field Warden's Torture Kit
            187240, -- Field Warden's Watchful Eye
        },
        label="Spectral Bound Chest",
        -- currency=1767, -- x40
        note="Click 3x nearby Spectral Keys to unlock",
    },
})

-- spectral keys
ns.RegisterPoints(1961, { -- Korthia
    [57504930] = {quest=64248, atlas="warfronts-basemapicons-alliance-workshop-minimap"},
    [58204870] = {quest=64248, atlas="warfronts-basemapicons-alliance-workshop-minimap"},
    [59205671] = {quest=64248, atlas="warfronts-basemapicons-alliance-workshop-minimap"},
    [61504735] = {quest=64248, atlas="warfronts-basemapicons-alliance-workshop-minimap"},
    [62755135] = {quest=64248, atlas="warfronts-basemapicons-alliance-workshop-minimap"},

    [50505370] = {quest=64249, atlas="warfronts-basemapicons-empty-workshop-minimap"},
    [52305320] = {quest=64249, atlas="warfronts-basemapicons-empty-workshop-minimap"},
    [52604970] = {quest=64249, atlas="warfronts-basemapicons-empty-workshop-minimap"},
    [54205060] = {quest=64249, atlas="warfronts-basemapicons-empty-workshop-minimap"},

    [59205670] = {quest=64250, atlas="warfronts-basemapicons-horde-workshop-minimap"},
    [60305650] = {quest=64250, atlas="warfronts-basemapicons-horde-workshop-minimap"},
    [61005870] = {quest=64250, atlas="warfronts-basemapicons-horde-workshop-minimap"},
    [62105770] = {quest=64250, atlas="warfronts-basemapicons-horde-workshop-minimap"},
}, {
    label = "Spectral Key",
    minimap=true,
})

-- Mawsworn cache
local mawcache = ns.nodeMaker{
    label = "Mawsworn Cache",
    loot = {
        187020, -- Necrobinder's Shoulderpads
        187026, -- Field Warden's Torture Kit
        187240, -- Field Warden's Watchful Eye
    },
    note = "Multiple spawn points",
}
ns.RegisterPoints(1961, { -- Korthia
    -- Cache one:
    [57553755] = mawcache(),
    [58803360] = mawcache(),
    [60103930] = mawcache(),
    [62903490] = mawcache(),
}, {
    quest=64021,
    texture=ns.atlas_texture("VignetteLoot", {r=1,g=0.5,b=0,a=1,scale=1}),
})
ns.RegisterPoints(1961, { -- Korthia
    -- Cache two:
    [56805610] = mawcache(),
    [58305285] = mawcache(),
    [61105160] = mawcache(),
    [61205790] = mawcache(),
    [62305860] = mawcache(),
}, {
    quest=64363,
    texture=ns.atlas_texture("VignetteLoot", {r=1,g=0.5,b=0.5,a=1,scale=1}),
})
ns.RegisterPoints(1961, { -- Korthia
    -- Cache three
    [47707430] = mawcache(),
    [47956675] = mawcache(),
    [51306480] = mawcache(),
    [54007280] = mawcache(),
    [56406950] = mawcache(),
    [56507470] = mawcache(),
}, {
    quest=64364,
    texture=ns.atlas_texture("VignetteLoot", {r=0.5,g=1,b=0.5,a=1,scale=1}),
})

-- Rift portals
ns.RegisterPoints(1961, { -- Korthia
    [41104210] = {}, -- 42304090
    [43504700] = {},
    [53707200] = {},
    [56807460] = {},
    [59405370] = {},
    [61804460] = {},
}, {
    label="{npc:179595}",
    atlas="poi-rift1",
    requires_no_buff={352795, 354870, any=true},
    note="Rifts let you enter an alternate phase, if you have a {item:186731}. There are rares and chests that're only in the rift.",
})

-- Riftbound Caches
local riftcache = ns.nodeMaker{
    label="Riftbound Cache",
    -- requires_item=186731, -- Repaired Riftkey
    loot={
        187251, -- Shaded Skull Shoulderguards
        187243, -- Shadehunter's Crescent
        {187276, quest=64522}, -- Stolen Korthian Supplies
        {185050, quest=63606, covenant=Enum.CovenantType.NightFae}, -- Spider Soul
        186017, -- Korthite Crystal
        RELIC_FRAGMENT,
    },
    active=rift_active,
    note="You need to be in the rift to see these.",
}
ns.RegisterPoints(1961, { -- Korthia
    [33453930] = riftcache(),
    [35953245] = riftcache(),
    [38003550] = riftcache(),
    [39804300] = riftcache(),
}, {
    quest=64456,
    texture=ns.atlas_texture("VignetteLoot", {r=1,g=0,b=0,a=1,scale=1}),
})
ns.RegisterPoints(1961, { -- Korthia
    [24805625] = riftcache(),
    [25955580] = riftcache(),
    [26555640] = riftcache(),
    [27555935] = riftcache(),
}, {
    quest=64470,
    texture=ns.atlas_texture("VignetteLoot", {r=0,g=1,b=0,a=1,scale=1}),
})
ns.RegisterPoints(1961, { -- Korthia
    [54105460] = riftcache(),
    [54904240] = riftcache(),
    [55506510] = riftcache(),
    [60903520] = riftcache(),
    [61755870] = riftcache(),
}, {
    quest=64471,
    texture=ns.atlas_texture("VignetteLoot", {r=0,g=0.5,b=1,a=1,scale=1}),
})
ns.RegisterPoints(1961, { -- Korthia
    [46103190] = riftcache(),
    [50753300] = riftcache(),
    [56301850] = riftcache(),
    [64303040] = riftcache(),
}, {
    quest=64472,
    texture=ns.atlas_texture("VignetteLoot", {r=1,g=1,b=0,a=1,scale=1}),
})

--Relics
local relic_traits = {
    minimap=true,
    atlas="reagents",
    onquest=true,
}

ns.RegisterPoints(1961, { -- Korthia
    [27305670] = researched{ -- Book of Binding: The Mad Witch
        achievement=15066, criteria=52131,
        quest=63899,
        research=2,
    },

    [45105610] = researched{ -- Celestial Shadowlands Chart
        achievement=15066, criteria=52258,
        quest=63912,
        research=2,
        minimap=false,
    },

    [43505760] = researched{ -- Gorak Claw Fetish
        -- actual chest is at 41156015
        achievement=15066, criteria=52268,
        quest=63924,
        -- requires_item=186984,
        research=2,
        note="In cave. Buy {item:186984} from {npc:178257} to unlock",
    },

    [41304330] = researched{ -- Guise of the Changeling
        achievement=15066, criteria=52255,
        quest=63909,
        -- requires_item=186984,
        research=2,
        loot={
            {187155, toy=true} -- Guise of the Changeling
        },
        note="Buy {item:186984} from {npc:178257} to unlock",
    },

    [33004190] = researched{ -- The Netherstar
        achievement=15066, criteria=52256,
        quest=63910,
        -- requires_item=186984,
        research=2,
        note="Buy {item:186984} from {npc:178257} to unlock",
    },

    [43857690] = researched{ -- Ring of Self-Reflection
        achievement=15066, criteria=52265,
        quest=63921,
        -- requires_item=186984,
        research=2,
        loot={
            {187140, toy=true} -- Ring of Duplicity
        },
        note="Buy {item:186984} from {npc:178257} to unlock",
    },

    [62005680] = researched{ -- Singing Steel Ingot
        achievement=15066, criteria=52257,
        quest=63911,
        research=2,
    },

    [39405240] = researched{ -- Drum of Driving
        achievement=15066, criteria=52269,
        quest=63915,
        -- requires_item=186718,
        research=3,
        note="Use {item:186718} from {npc:178257} on the Ancient Teleporter",
    },

    [45003550] = researched{ -- Sack of Strange Soil
        achievement=15066, criteria=52261,
        quest=63916,
        -- requires_item=186718,
        research=3,
        note="Use {item:186718} from {npc:178257} on the Ancient Teleporter",
    },

    [40504140] = researched{ -- Talisman of the Eternal Scholar
        achievement=15066, criteria=52126,
        quest=63860,
        research=3,
        note="In cave",
    },

    [60803490] = researched{ -- Book of Binding: The Tormented Sorcerer
        achievement=15066, criteria=52264,
        quest=63919,
        -- requires_item=186731,
        research=4,
        active=rift_active,
        note="Buy {item:186731} from {npc:178257} to enter the rift",
    },

    [29005420] = researched{ -- Cipher of Understanding
        achievement=15066, criteria=52260,
        quest=63914,
        -- requires_item=186731,
        research=4,
        active=rift_active,
        note="Buy {item:186731} from {npc:178257} to enter the rift",
    },

    [52005260] = researched{ -- Enigmatic Decrypting Device
        achievement=15066, criteria=52270,
        quest=63920,
        -- requires_item=186731,
        research=4,
        active=rift_active,
        note="Buy {item:186731} from {npc:178257} to enter the rift",
    },

    [51402010] = researched{ -- Unstable Sin'dorei Explosive
        achievement=15066, criteria=52259,
        quest=63913,
        -- requires_item=186731,
        research=4,
        active=rift_active,
        note="Buy {item:186731} from {npc:178257} to enter the rift",
    },

    [18503800] = researched{ -- Bulwark of Divine Intent
        achievement=15066, criteria=52254,
        quest=63908,
        research=5,
        note="Use the shrine to get {spell:352367} to see the altar path",
    },

    [24355660] = researched{ -- Lang Family Wood-Carving
        achievement=15066, criteria=52267,
        quest=63923,
        research=5,
        note="Use the shrine to get {spell:352367} to see the altar path",
    },

    [39404270] = researched{ -- Shadow Slicing Sword
        achievement=15066, criteria=52266,
        quest=63922,
        research=5,
        loot={
            {187159, toy=true}, -- Shadow Slicing Shortsword
        },
        note="Use the shrine to get {spell:352367} to see the altar path",
    },
}, relic_traits)

ns.RegisterPoints(2007, { -- Gromit Hollow
    [39304920] = researched{ -- Book of Binding: The Mad Witch
        achievement=15066, criteria=52131,
        quest=63899,
        research=2,
    },
}, relic_traits)

--Maelie
ns.RegisterPoints(1961, { -- Korthia
    [60552105] = { -- Tinybell
        quest=64292,
        label="{npc:179930}",
        atlas="stablemaster",
        texture=false,
    },
    -- Maelie
    [30005560] = {},
    [35804650] = {}, -- on chain
    [35856225] = {note="Climb along the blue lines from the northeast"},
    [38403140] = {}, -- on shelf, jump down
    [39703490] = {}, -- among roots, jump down
    [41103980] = {}, -- middle level of cliffs
    [41302750] = {}, -- looking into Maw
    [42806040] = {},
    [43203130] = {}, -- on hill
    [49304170] = {}, -- among roots
    [50302290] = {}, -- on cliff, walk from above
    [59801510] = {}, -- on cliff
    [61304040] = {}, -- on cliff
    [62404970] = {}, -- by cliff behind large tree
}, {
    quest={64292,64298,any=true}, -- 2 is the final mount-quest, 8 is found-today
    progress={64293, 64294, 64295, 64296, 64297, 64292},
    label="{npc:179912}",
    texture=ns.merge(ns.atlas_texture("stablemaster"), {r=0,g=1,b=1,a=1,scale=1.2}),
    minimap=true,
    loot={
        {186643, mount=1511}, -- Reins of the Wanderer
    },
    note="{npc:179930} asks you to find {npc:179912}, who spawns in a different place each day. Find her each day, use {spell:355862} on her, and get a mount from {npc:179930}.",
})

ns.RegisterPoints(1961, { -- Korthia
    [42853270] = { -- Darkmaul
        quest=64376, progress=0,
        npc=180063,
        texture=ns.merge(ns.atlas_texture("stablemaster"), {r=1,g=0,b=1,a=1,scale=1.2}),
        loot={
            {186646, mount=1507}, -- Darkmaul
        },
        note="Feed {item:187153} from Invasive Mawshrooms to {npc:180063} 10 times.",
    },
    [25725108] = { -- Razorwing Nest
        quest=64274, progress=0,
        npc=179871,
        texture=ns.merge(ns.atlas_texture("stablemaster"), {r=1,g=1,b=0,a=1,scale=1.2}),
        loot={
            {186651, mount=1510}, -- Dusklight Razorwing
        },
        note=function()
            local function qp(...)
                for i=1, select('#', ...) do
                    if not C_QuestLog.IsQuestFlaggedCompleted((select(i, ...))) then
                        return i - 1
                    end
                end
                return select('#', ...)
            end
            -- egg drop tracker: 64280, 64281
            return "Get 2x {item:187054} per day from devourers, turn in 10 at the nest for the mount.\n"..
                "Eggs found today: " .. qp(64280, 64281)
        end,
    },
}, {
    minimap=true,
})

--Rares
ns.RegisterPoints(1961, { -- Korthia
    [58201775] = { -- Assault Supply Carriage
        npc=180246,
        quest=64258, -- 64439?
        achievement=15107, criteria=52290,
        loot={
            187370, -- Carriage Crusher's Padded Slippers
            187391, -- Yarxhov's Rib-Cage
            187399, -- Maw Construct's Shoulderguards
        },
    },

    [51154165] = { -- Consumption
        achievement=15107, criteria=52285,
        quest=64243,
        npc=179768, -- 179769 (normal), 179755 (rare)
        loot={
            187245, -- Death-Enveloped Spires
            187246, -- Death-Enveloped Pauldrons
            187247, -- Death-Enveloped Shoulder Spikes
            187402, -- All-Consuming Loop
        },
        note="Starts as an elite, eats {npc:179344} until it becomes a rare and then a rare-elite. Loot gets better as it gets stronger, so wait.",
    },

    [59355220] = { -- Deadsoul Hatcher
        achievement=15107, criteria=52275,
        quest=64285,
        npc=179913,
        requires_item=186731,
        loot={
            -- {187174, toy=true}, -- Shaded Judgement Stone (apparently not off-PTR?)
            187396, -- Girdle of the Deadsoul
            187401, -- Band of the Shaded Rift
        },
        active=rift_active,
        note="Buy {item:186731} from {npc:178257} to enter the rift",
    },


    [51802080] = { -- Dominated Protector
        achievement=15107, criteria=52277,
        quest=63830,
        npc=177903,
        loot={
            187390, -- Dominated Protector's Helm
        },
    },

    [33103930] = { -- Escaped Wilderling
        achievement=15107, criteria=52298,
        quest=64320,
        npc=180014,
        covenant=Enum.CovenantType.NightFae,
        loot={
            {186492, mount=1487, covenant=Enum.CovenantType.NightFae}, -- Summer Wilderling Harness
        },
        note="Click on the {npc:180014} to start",
    },

    [59954370] = { -- Fleshwing (Corpse Heap)
        achievement=15107, criteria=52299,
        quest=64349,
        npc=180042,
        -- covenant=Enum.CovenantType.Necrolord,
        loot={
            187372, -- Miasma Filtering Headpiece
            {186489, mount=1449, covenant=Enum.CovenantType.Necrolord}, -- Lord of the Corpseflies (from 187181)
            {187424, quest=64551,}, -- Legend of the Animaswell
        },
        note="Talk to {npc:180079}",
    },

    [59203580] = { -- Kroke the Tormented
        achievement=15107, criteria=52304,
        quest=64428,
        npc=179108,
        loot={
            187394, -- Tormented Giant's Legplates
            187250, -- Kroke's Wingspiked Pauldrons
            187248, -- Kroke's Gleaming Spaulders
        },
    },

    [44202950] = { -- Malbog
        achievement=15107, criteria=52283,
        quest=64233,
        npc=179684,
        loot={
            {186645, mount=1506}, -- Crimson Shardhide
            187377, -- Malbog's Paws
        },
        note="Talk to {npc:179729} in town to gain {spell:355078} and follow footprints",
    },
    [60652315] = {
        achievement=15107, criteria=52283,
        quest=64233,
        label="{npc:179729}", note="Get {spell:355078} and follow the footprints to 44.2, 29.5",
        atlas="ancientmana",
    },

    [50307590] = { -- Observer Yorik
        achievement=15107, criteria=52294,
        quest=64369,
        npc=179914,
        -- requires_item=186731,
        loot={
            {187420, toy=true}, -- Maw-Ocular Viewfinder
            187365, -- Rift Splitter
            187405, -- Choker of the Hidden Observer
        },
        active=rift_active,
        note="Buy {item:186731} from {npc:178257} to enter the rift",
    },

    [22604140] = { -- Relic Breaker Krelva
        achievement=15107, criteria=52291,
        quest=64291,
        npc=179931,
        loot={
            187403, -- Relic Breaker's Drape
        },
    },

    [56256615] = { -- Reliwik the Defiant
        achievement=15107, criteria=52318,
        quest=64455,
        npc=180160,
        loot={
            {186652, mount=1509}, -- Garnet Razorwing
            187388, -- Barbed Scale Cinch
        },
        note="Summon with the uncorrupted razorwing egg",
    },

    [44604240] = { -- Screaming Shade
        achievement=15107, criteria=52273,
        quest=64263,
        npc=179608,
        loot={
            187362, -- Stinging Shadow Screamer
            187400, -- Mantle of Screaming Shadows
        },
        active=rift_active,
        note="Buy {item:186731} from {npc:178257} to enter the rift",
    },

    [57607040] = { -- Silent Soulstalker
        achievement=15107, criteria=52274,
        quest=64284,
        npc=179911,
        loot={
            187381, -- Rift-Touched Bindings
            187383, -- Silent Soulstalker Sabatons
        },
        active=rift_active,
        note="Buy {item:186731} from {npc:178257} to enter the rift",
    },

    [46507950] = { -- Stygian Stonecrusher (No Stoneborn Left Behind)
        achievement=15107, criteria=52276,
        quest=64313,
        npc=179985,
        covenant=Enum.CovenantType.Venthyr,
        loot={
            184790, -- Archdruid Van-Yali's Greenthumbs
            {186479, mount=nil, covenant=Enum.CovenantType.Venthyr}, -- Mastercraft Gravewing
            -- {187283,quest=64530,}, -- Gravewing Crystal
            187386, -- Stygian Crystal Studded Legguards
            {187428,quest=64553,}, -- Legend of the Animaswell
        },
        note="Talk to {npc:179974}",
    },

    [56853235] = { -- Wild Worldcracker (Popo's Potion Patrol)
        achievement=15107, criteria=52300,
        quest=64338,
        npc=180032,
        covenant=Enum.CovenantType.Kyrian,
        loot={
            {187176, toy=true}, -- Vesper of Harmony
            {186483, mount=1493, covenant=Enum.CovenantType.Kyrian}, -- Foresworn Aquilon
            -- {187282,quest=64529,}, -- Intact Aquilon Core
            187380, -- Devourer Hide Belt
            {187426,quest=64552,}, -- Legend of the Animaswell
        },
        note="Talk to {npc:180028}",
    },

    [44903550] = { -- Xyraxz the Unknowable (Chamber of Wisdom)
        achievement=15107, criteria=52296,
        achievement=15066, criteria=52263,
        quest=64278,
        npc=179859,
        -- requires_item=186718,
        loot={
            {186538, pet=3140}, -- Gnashtooth
            {187104, quest=63918}, -- Obelisk of Dark Tidings
            187387, -- Pauldrons of the Unknown Beyond
            187368, -- Xyraxz's Controlling Rod
        },
        note="Use {item:186718} from {npc:178257} on the Ancient Teleporter",
    },

    [39405240] = { -- Yarxhov the Pillager (Chamber of Knowledge)
        achievement=15107, criteria=52295,
        achievement=15066, criteria=52262,
        quest=64257,
        npc=179802,
        -- requires_item=186718,
        loot={
            {187103, quest=63917}, -- Everliving Statuette
            187366, -- Fallen Vault Guardian's Spire
            187391, -- Yarxhov's Rib-Cage
        },
        note="Use {item:186718} from {npc:178257} on the Ancient Teleporter",
    },

    [27755885] = { -- Zelnithop
        achievement=15107, criteria=52301,
        quest=64442,
        npc=177336,
        loot={
            {186542, pet=3136}, --Korthian Specimen
            187371, -- Velvet Gromit Handwraps
        },
        note="In cave",
    },
    [30305480] = path({achievement=15107, criteria=52301, quest=64442,}),

    -- the many-spawn ones

    [10008000] = { -- Konthrogz the Obliterator
        achievement=15107, criteria=52303,
        quest=64246, -- 64280?
        npc=179472,
        loot={
            {187183, mount=1514}, -- Rampaging Mauler
            187375, -- Bound Worldeater Tendrils
            187378, -- Visage of the Obliterator
            187384, -- Konthrogz's Scaled Handguards
            187397, -- Vambraces of the In-Between
        },
        note="Spawns in a devourer portal event",
    },
    [12008000] = { -- Towering Exterminator
        achievement=15107, criteria=52302,
        quest=64245,
        npc=179760,
        loot={
            187035, -- Cold Burden of the Damned
            187241, -- Watchful Eye of the Damned
            187242, -- Exterminator's Crest of the Damned
            187373, -- Soul-Enveloping Leggings
            187376, -- Mawsworn Lieutenant's Treads
            187382, -- Mawsworn Exterminator's Hauberk
            187392, -- Sabatons of the Towering Construct
        },
        note="Spawns in a mawsworn portal event",
    },
    [14008000] = { -- Ve'rayn (Pop Quiz)
        achievement=15107, criteria=52319,
        quest=64457,
        npc=180162,
        loot={
            {187264, quest=64513}, -- Ve'rayn's Head
            187369, -- Ve'rayn's Formal Robes
            187404, -- Cartel Ve Amulet
        },
        note="Find and use the Abandoned Veilstaff, then talk to {npc:180162}",
    },
})

-- Teleporters

--Waystone
ns.RegisterPoints(1961, {
    [64502400] = {
        label="Waystone to Oribos",
        atlas="adventures-32x32", scale=1.2,
        active={quest=63665},
        minimap=true,
    },
})
-- Flayedwing
ns.RegisterPoints(1961, {
    [60852855] = {route=49356385,},
    [49356385] = {route={49356385,60852855,r=0,g=0.75,b=0},},
}, {
    label="{npc:180548}",
    atlas="flightmaster", scale=1.2,
    active={quest=63665},
})
